@@ -4,9 +4,7 @@ require "signet"
 module Signet # :nodoc:
   module OAuth1
     module HMACSHA1
-      def self.generate_signature \
-          base_string, client_credential_secret, token_credential_secret
-
+      def self.generate_signature base_string, client_credential_secret, token_credential_secret
         # Both the client secret and token secret must be escaped
         client_credential_secret =
           Signet::OAuth1.encode client_credential_secret
