@@ -6,10 +6,7 @@ require "signet"
 module Signet # :nodoc:
   module OAuth1
     module RSASHA1
-      def self.generate_signature \
-          base_string, client_credential_secret, _token_credential_secret
-
-
+      def self.generate_signature base_string, client_credential_secret, _token_credential_secret
         private_key = OpenSSL::PKey::RSA.new client_credential_secret
         signature = private_key.sign OpenSSL::Digest.new("SHA1"), base_string
         # using strict_encode64 because the encode64 method adds newline characters after ever 60 chars
